from pydantic import BaseModel
from typing import Any, List, Set


class Message(BaseModel):
    text: str

    def __str__(self):
        return self.text


class InHouseApiModel(BaseModel):
    msgType: str
    data: Any


class TickerDto(BaseModel):
    conId: int
    symbol: Any
    price: float
    # volume: Any


class TickerList(BaseModel):
    tickers: List[TickerDto]


class ContractMetaData(BaseModel):
    symbol: str
    secType: str
    exchange: str
    multiplier: float = None
    monthOfContract: str = None
    tickSize: float = None


class ContractMetaDataList(BaseModel):
    contracts: List[ContractMetaData]



from setuptools import setup, find_packages

setup(
    name="jgib",
    packages=find_packages(),  # Automatically finds and includes all submodules in `jgmd`
    version="1.0.0",
    license="MIT",
    description="A general-purpose python package for logging, event-emission, and other common code.",
    author="Jonathan Gardner",
    author_email="rjgardnermd@gardnermoneygrowth.com",
    url="https://github.com/rjgardnermd/jgib",
    download_url="https://github.com/rjgardnermd/jgib/archive/refs/tags/v1.0.0.tar.gz",
    keywords=[
        "PYTHON",
        "IBKR",
        "DTO",
        "MODELS",
    ],
    install_requires=["pydantic"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.13",
    ],
)
